==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/NonLocalEventSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.NonLocalEvent;
import io.ciera.tool.sql.ooaofooa.statemachine.NonLocalEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.PolymorphicEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SEMEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.PolymorphicEventSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SEMEventSetImpl;

import java.util.Arrays;
import java.util.List;


public class NonLocalEventSetImpl extends InstanceSet<NonLocalEventSet,NonLocalEvent> implements NonLocalEventSet {

    // attributes
    @Override
    public void setLocal_Meaning( String m_Local_Meaning ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setLocal_Meaning( m_Local_Meaning );
    }
    @Override
    public void setPolySMevt_ID( UniqueId ref_polySMevt_ID ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setPolySMevt_ID( ref_polySMevt_ID );
    }
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setPolySM_ID( UniqueId ref_polySM_ID ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setPolySM_ID( ref_polySM_ID );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setName( m_Name );
    }
    @Override
    public void setPolySMspd_IDdeprecated( UniqueId m_polySMspd_IDdeprecated ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setPolySMspd_IDdeprecated( m_polySMspd_IDdeprecated );
    }
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setSMevt_ID( ref_SMevt_ID );
    }


    // selections
    @Override
    public SEMEventSet R526_is_a_SEMEvent() throws XtumlException {
        SEMEventSet semeventset = new SEMEventSetImpl();
        for ( NonLocalEvent nonlocalevent : this ) semeventset.add( nonlocalevent.R526_is_a_SEMEvent() );
        return semeventset;
    }
    @Override
    public PolymorphicEventSet R527_is_defined_by_PolymorphicEvent() throws XtumlException {
        PolymorphicEventSet polymorphiceventset = new PolymorphicEventSetImpl();
        for ( NonLocalEvent nonlocalevent : this ) polymorphiceventset.add( nonlocalevent.R527_is_defined_by_PolymorphicEvent() );
        return polymorphiceventset;
    }


    @Override
    public NonLocalEvent nullElement() {
        return NonLocalEventImpl.EMPTY_NONLOCALEVENT;
    }

    @Override
    public NonLocalEventSet emptySet() {
      return new NonLocalEventSetImpl();
    }

    @Override
    public NonLocalEventSet value() {
        return this;
    }

    @Override
    public List<NonLocalEvent> elements() {
        NonLocalEvent[] elements = toArray(new NonLocalEvent[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/NonLocalEventSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.NonLocalEvent;
import io.ciera.tool.sql.ooaofooa.statemachine.NonLocalEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.PolymorphicEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SEMEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.PolymorphicEventSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SEMEventSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class NonLocalEventSetImpl extends InstanceSet<NonLocalEventSet,NonLocalEvent> implements NonLocalEventSet {

    public NonLocalEventSetImpl() {
    }

    public NonLocalEventSetImpl(Comparator<? super NonLocalEvent> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setSMevt_ID( ref_SMevt_ID );
    }
    @Override
    public void setPolySM_ID( UniqueId ref_polySM_ID ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setPolySM_ID( ref_polySM_ID );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setName( m_Name );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setPolySMspd_IDdeprecated( UniqueId m_polySMspd_IDdeprecated ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setPolySMspd_IDdeprecated( m_polySMspd_IDdeprecated );
    }
    @Override
    public void setPolySMevt_ID( UniqueId ref_polySMevt_ID ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setPolySMevt_ID( ref_polySMevt_ID );
    }
    @Override
    public void setLocal_Meaning( String m_Local_Meaning ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setLocal_Meaning( m_Local_Meaning );
    }
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( NonLocalEvent nonlocalevent : this ) nonlocalevent.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }


    // selections
    @Override
    public SEMEventSet R526_is_a_SEMEvent() throws XtumlException {
        SEMEventSet semeventset = new SEMEventSetImpl();
        for ( NonLocalEvent nonlocalevent : this ) semeventset.add( nonlocalevent.R526_is_a_SEMEvent() );
        return semeventset;
    }
    @Override
    public PolymorphicEventSet R527_is_defined_by_PolymorphicEvent() throws XtumlException {
        PolymorphicEventSet polymorphiceventset = new PolymorphicEventSetImpl();
        for ( NonLocalEvent nonlocalevent : this ) polymorphiceventset.add( nonlocalevent.R527_is_defined_by_PolymorphicEvent() );
        return polymorphiceventset;
    }


    @Override
    public NonLocalEvent nullElement() {
        return NonLocalEventImpl.EMPTY_NONLOCALEVENT;
    }

    @Override
    public NonLocalEventSet emptySet() {
      return new NonLocalEventSetImpl();
    }

    @Override
    public NonLocalEventSet emptySet(Comparator<? super NonLocalEvent> comp) {
      return new NonLocalEventSetImpl(comp);
    }

    @Override
    public NonLocalEventSet value() {
        return this;
    }

    @Override
    public List<NonLocalEvent> elements() {
        NonLocalEvent[] elements = toArray(new NonLocalEvent[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
